@@ -1,7 +1,8 @@
 import asyncio
 import logging
 import time
-from typing import Callable, Awaitable
+import uuid
+from typing import Callable, Awaitable, Dict, Any, Type
 
 logger = logging.getLogger(__name__)
 
@@ -13,6 +14,12 @@ def timestamp() -> int:
     return int(round(time.time() * 1000))
 
 
+def check_event(event: Dict[str, Any]) -> Dict[str, Any]:
+    assert "type" in event
+    defaults = {"timestamp": timestamp(), "pc_client_id": str(uuid.uuid4())}
+    return {**defaults, **event}
+
+
 class RetryException(Exception):
     pass
 
@@ -21,7 +28,7 @@ async def retry_with_backoff(
     wrapped: Callable[[], Awaitable],
     retries: int = 5,
     retry_exponent: float = 3.0,
-    exc_type: Exception = Exception,
+    exc_type: Type[BaseException] = BaseException,
 ):
     for trial in range(1, retries + 1):
         try:
